@@ -5,7 +5,7 @@ import mimetypes
 import asyncio
 from tornado.ioloop import IOLoop
 import time
-import cortx_constants
+from .constants import (NB_TYPE,UNTITLED_FILE,FOLDER_SEPERATOR,UNTITLED_NB,UNTITLED_FOLDER,CHECKPOINT_NAME)
 
 from tornado.web import HTTPError as HTTPServerError
 import base64
@@ -35,7 +35,7 @@ CredentialConfig = namedtuple('CredentialConfig', [
     'access_key_id', 'secret_access_key'
 ])
 
-cortx_constants = {'NB_TYPE' :'.ipynb', 'UNTITLED_FILE' :'Untitled', 'FOLDER_SEPERATOR' : '/', 'UNTITLED_NB' :'Untitled', 'UNTITLED_FOLDER' : 'Untitled Folder','CHECKPOINT_NAME' : '.checkpoints'}
+# cortx_constants = {'NB_TYPE' :'.ipynb', 'UNTITLED_FILE' :'Untitled', 'FOLDER_SEPERATOR' : '/', 'UNTITLED_NB' :'Untitled', 'UNTITLED_FOLDER' : 'Untitled Folder','CHECKPOINT_NAME' : '.checkpoints'}
 
 class ExpiringDict:
 
@@ -211,7 +211,7 @@ def _final_path_component(key_or_path):
     return key_or_path.split('/')[-1]
 
 def _copy_sort_key(key):
-    return (key.count('/'), 0 if key.endswith(cortx_constants['FOLDER_SEPERATOR']) else 1)
+    return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
 
 def _delete_sort_key(key):
@@ -220,7 +220,7 @@ def _delete_sort_key(key):
 @gen.coroutine
 def _type_from_path(config, path):
     type = \
-        'notebook' if path.endswith(cortx_constants["NB_TYPE"]) else \
+        'notebook' if path.endswith(NB_TYPE) else \
         'directory' if _is_root(path) or (yield _dir_exists(config, path)) else \
         'file'
     return type
@@ -237,14 +237,14 @@ def _format_from_type_and_path(config, type, path):
 
 def _type_from_path_not_directory(path):
     type = \
-        'notebook' if path.endswith(cortx_constants["NB_TYPE"]) else \
+        'notebook' if path.endswith(NB_TYPE) else \
         'file'
     return type
 
 
 @gen.coroutine
 def _dir_exists(config, path):
-    return True if _is_root(path) else (yield _file_exists(config, path + cortx_constants["FOLDER_SEPERATOR"]))
+    return True if _is_root(path) else (yield _file_exists(config, path + FOLDER_SEPERATOR))
 
 
 def _is_root(path):
@@ -361,7 +361,7 @@ def _get_directory(config, path, content):
                 'last_modified': last_modified,
             }
             for (key, last_modified) in keys
-            if not key.endswith(cortx_constants["FOLDER_SEPERATOR"])
+            if not key.endswith(FOLDER_SEPERATOR)
         ]) if content else None
     }
 
@@ -396,7 +396,7 @@ def _save_file_text(config, chunk, content, path):
 
 @gen.coroutine
 def _save_directory(config, chunk, content, path):
-    return (yield _save_any(config, chunk, b'', path + cortx_constants["FOLDER_SEPERATOR"], 'directory', None))
+    return (yield _save_any(config, chunk, b'', path + FOLDER_SEPERATOR, 'directory', None))
 
 
 @gen.coroutine
@@ -463,7 +463,7 @@ def _increment_filename(config, filename, path='', insert=''):
 
 
 def _checkpoint_path(path, checkpoint_id):
-    return path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/' + checkpoint_id
+    return path + '/' + CHECKPOINT_NAME + '/' + checkpoint_id
 
 
 @gen.coroutine
@@ -506,11 +506,11 @@ def _delete_checkpoint(config, checkpoint_id, path):
 
 @gen.coroutine
 def _list_checkpoints(config, path):
-    key_prefix = _key(config, path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/')
+    key_prefix = _key(config, path + '/' + CHECKPOINT_NAME + '/')
     keys, _ = yield _list_immediate_child_keys_and_directories(config, key_prefix)
     return [
         {
-            'id': key[(key.rfind('/' + cortx_constants["CHECKPOINT_NAME"] + '/') + len('/' + cortx_constants["CHECKPOINT_NAME"] + '/')):],
+            'id': key[(key.rfind('/' + CHECKPOINT_NAME + '/') + len('/' + CHECKPOINT_NAME + '/')):],
             'last_modified': last_modified,
         }
         for key, last_modified in keys
@@ -597,9 +597,9 @@ def _new_untitled(config, path, type, ext):
         'file'
 
     untitled = \
-        cortx_constants["UNTITLED_FOLDER"] if model_type == 'directory' else \
-        cortx_constants["UNTITLED_NB"] if model_type == 'notebook' else \
-        cortx_constants["UNTITLED_FILE"]
+        UNTITLED_FOLDER if model_type == 'directory' else \
+        UNTITLED_NB if model_type == 'notebook' else \
+        UNTITLED_FILE
     insert = \
         ' ' if model_type == 'directory' else \
         ''
